@@ -127,7 +127,6 @@ def _fill_index_names(
 
     for idx, name in enumerate(index_names, start=start_row):
         cell: TableCell = table_docx.cell(idx, 0)
-        print(name)
         cell.text = name
         _style_index_names(cell)
 
@@ -306,9 +305,6 @@ class Table:
         heading.alignment = CENTER
         heading.runs[0].font.size = Pt(10)
 
-        print(self._data)
-        print(self._data.index)
-
         render_table(
             self._data,
             self._color,
